"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.filterDependencies = filterDependencies;
exports.partitionDependencies = partitionDependencies;

var _micromatch = _interopRequireDefault(require("micromatch"));

var logger = _interopRequireWildcard(require("./logger"));

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// Filter out dependencies that are in blocklist
function filterDependencies(packageDependencies, isApp) {
  if (isApp) {
    return {
      bundled: packageDependencies,
      external: {}
    };
  }

  const externalBlockList = process.env.EXTERNAL_BLOCK_LIST && !isApp ? process.env.EXTERNAL_BLOCK_LIST.split(',') : undefined;
  const externalAllowList = process.env.EXTERNAL_ALLOW_LIST && !isApp ? process.env.EXTERNAL_ALLOW_LIST.split(',') : undefined;
  logger.debug('Filtering dependencies...');
  logger.debug(`External block list for dependencies is: ${JSON.stringify(externalBlockList)}`);
  logger.debug(`External allow list for dependencies is: ${JSON.stringify(externalAllowList)}`);
  return partitionDependencies({
    packageDependencies,
    allowList: externalAllowList,
    blockList: externalBlockList
  });
}

function partitionDependencies({
  packageDependencies,
  // By default, everything is externalized
  allowList: externalizeList = ['**'],
  // By default, nothing is bundled
  blockList: bundleList = []
}) {
  return Object.entries(packageDependencies).reduce((acc, [name, version]) => {
    const isBlocked = _micromatch.default.isMatch(name, bundleList);

    const isAllowed = _micromatch.default.isMatch(name, externalizeList);

    logger.debug(`Dependency ${name} isBlocked:${isBlocked.toString()}, isAllowed: ${isAllowed.toString()}`); // It's not enough to be in allow list, the dependency should also not be in block list to be rewritten

    if (isAllowed && !isBlocked) {
      acc.external[name] = version;
    } else {
      acc.bundled[name] = version;
    }

    return acc;
  }, {
    external: {},
    bundled: {}
  });
}
//# sourceMappingURL=filterDependencies.js.map